LZ4
===
.. automodule:: numcodecs.lz4

.. autoclass:: LZ4

    .. autoattribute:: codec_id
    .. automethod:: encode
    .. automethod:: decode
    .. automethod:: get_config
    .. automethod:: from_config

Helper functions
----------------

.. autofunction:: compress
.. autofunction:: decompress
